==> tunacode_cli-0.0.31.tar.gz: tunacode_cli-0.0.31/tests/integration/test_mcp_tool_flow.py <==
"""
Integration Test: MCP Tool Flow

Tests MCP tool integration using real logic where possible, with heavy mocking at the subprocess/network boundary.

Scenario:
- Mocks MCPServerStdio.client_streams to simulate a successful connection.
- Calls get_mcp_servers and checks that a server is returned and can be used.

If the MCP client logic is not available, this test serves as a placeholder.

"""

import pytest
import asyncio
from unittest.mock import patch, AsyncMock, MagicMock

from tunacode.services import mcp as mcp_module
from tunacode.core.state import StateManager

@pytest.mark.asyncio
async def test_mcp_tool_flow(monkeypatch):
    # Patch client_streams to simulate a successful async context manager
    class FakeStream:
        async def __aenter__(self): return (MagicMock(), MagicMock())
        async def __aexit__(self, exc_type, exc, tb): pass

    monkeypatch.setattr(
        mcp_module.QuietMCPServer,
        "client_streams",
        FakeStream().__aenter__
    )

    # Patch MCPServerStdio init to avoid real subprocesses
    monkeypatch.setattr(
        mcp_module.QuietMCPServer,
        "__init__",
        lambda self, *a, **kw: None
    )

    # Create a minimal state manager
    state_manager = StateManager()

    # Call get_mcp_servers and check that a server is returned
    servers = mcp_module.get_mcp_servers(state_manager)
    assert isinstance(servers, list)
    # If configuration is empty, servers may be empty; this is acceptable for placeholder

"""
Notes:
- This test mocks the MCP server's client_streams to avoid real subprocess/network calls.
- If MCP configuration is not present, the test still validates the integration boundary.
- For real MCP integration, provide a test MCP server binary and configuration.
"""

==> tunacode_cli-0.0.42.tar.gz: tunacode_cli-0.0.42/tests/integration/test_mcp_tool_flow.py <==
"""
Integration Test: MCP Tool Flow

Tests MCP tool integration using real logic where possible, with heavy mocking at the subprocess/network boundary.

Scenario:
- Mocks MCPServerStdio.client_streams to simulate a successful connection.
- Calls get_mcp_servers and checks that a server is returned and can be used.

If the MCP client logic is not available, this test serves as a placeholder.

"""

from unittest.mock import MagicMock

import pytest

from tunacode.core.state import StateManager
from tunacode.services import mcp as mcp_module


@pytest.mark.asyncio
async def test_mcp_tool_flow(monkeypatch):
    # Patch client_streams to simulate a successful async context manager
    class FakeStream:
        async def __aenter__(self):
            return (MagicMock(), MagicMock())

        async def __aexit__(self, exc_type, exc, tb):
            pass

    monkeypatch.setattr(mcp_module.QuietMCPServer, "client_streams", FakeStream().__aenter__)

    # Patch MCPServerStdio init to avoid real subprocesses
    monkeypatch.setattr(mcp_module.QuietMCPServer, "__init__", lambda self, *a, **kw: None)

    # Create a minimal state manager
    state_manager = StateManager()

    # Call get_mcp_servers and check that a server is returned
    servers = mcp_module.get_mcp_servers(state_manager)
    assert isinstance(servers, list)
    # If configuration is empty, servers may be empty; this is acceptable for placeholder


"""
Notes:
- This test mocks the MCP server's client_streams to avoid real subprocess/network calls.
- If MCP configuration is not present, the test still validates the integration boundary.
- For real MCP integration, provide a test MCP server binary and configuration.
"""
